==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/inputs/VirtualNodeSpecListenerTlsCertificateAcmArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.inputs

import com.pulumi.aws.appmesh.inputs.VirtualNodeSpecListenerTlsCertificateAcmArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property certificateArn ARN for the certificate.
 */
public data class VirtualNodeSpecListenerTlsCertificateAcmArgs(
    public val certificateArn: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.appmesh.inputs.VirtualNodeSpecListenerTlsCertificateAcmArgs> {
    override fun toJava(): com.pulumi.aws.appmesh.inputs.VirtualNodeSpecListenerTlsCertificateAcmArgs =
        com.pulumi.aws.appmesh.inputs.VirtualNodeSpecListenerTlsCertificateAcmArgs.builder()
            .certificateArn(certificateArn.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VirtualNodeSpecListenerTlsCertificateAcmArgs].
 */
@PulumiTagMarker
public class VirtualNodeSpecListenerTlsCertificateAcmArgsBuilder internal constructor() {
    private var certificateArn: Output<String>? = null

    /**
     * @param value ARN for the certificate.
     */
    @JvmName("brjmdpooqliebyxp")
    public suspend fun certificateArn(`value`: Output<String>) {
        this.certificateArn = value
    }

    /**
     * @param value ARN for the certificate.
     */
    @JvmName("prfkbupvarkbfwjp")
    public suspend fun certificateArn(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.certificateArn = mapped
    }

    internal fun build(): VirtualNodeSpecListenerTlsCertificateAcmArgs =
        VirtualNodeSpecListenerTlsCertificateAcmArgs(
            certificateArn = certificateArn ?: throw PulumiNullFieldException("certificateArn"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/inputs/VirtualNodeSpecListenerTlsCertificateAcmArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.inputs

import com.pulumi.aws.appmesh.inputs.VirtualNodeSpecListenerTlsCertificateAcmArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property certificateArn ARN for the certificate.
 */
public data class VirtualNodeSpecListenerTlsCertificateAcmArgs(
    public val certificateArn: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.appmesh.inputs.VirtualNodeSpecListenerTlsCertificateAcmArgs> {
    override fun toJava(): com.pulumi.aws.appmesh.inputs.VirtualNodeSpecListenerTlsCertificateAcmArgs = com.pulumi.aws.appmesh.inputs.VirtualNodeSpecListenerTlsCertificateAcmArgs.builder()
        .certificateArn(certificateArn.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VirtualNodeSpecListenerTlsCertificateAcmArgs].
 */
@PulumiTagMarker
public class VirtualNodeSpecListenerTlsCertificateAcmArgsBuilder internal constructor() {
    private var certificateArn: Output<String>? = null

    /**
     * @param value ARN for the certificate.
     */
    @JvmName("wjphxluysdcrkcta")
    public suspend fun certificateArn(`value`: Output<String>) {
        this.certificateArn = value
    }

    /**
     * @param value ARN for the certificate.
     */
    @JvmName("pbschqoppwkvhnch")
    public suspend fun certificateArn(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.certificateArn = mapped
    }

    internal fun build(): VirtualNodeSpecListenerTlsCertificateAcmArgs =
        VirtualNodeSpecListenerTlsCertificateAcmArgs(
            certificateArn = certificateArn ?: throw PulumiNullFieldException("certificateArn"),
        )
}
